"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Juejin = void 0;
const base_1 = require("../base");
const axios_1 = __importDefault(require("axios"));
const sitdown_1 = require("sitdown");
const decorator_1 = require("../../decorator");
const log_1 = require("../../log");
const sitdown = new sitdown_1.Sitdown({
    keepFilter: ['style'],
    codeBlockStyle: 'fenced',
    bulletListMarker: '-',
    hr: '---',
});
class Juejin extends base_1.Base {
    constructor() {
        super(...arguments);
        this.headers = {};
    }
    getMain() {
        return __awaiter(this, void 0, void 0, function* () {
            const articleIds = [];
            let cursor = 0;
            while (true) {
                const { data: res } = yield axios_1.default.post('https://api.juejin.cn/content_api/v1/article/query_list', {
                    cursor: String(cursor),
                    sort_type: 2,
                    user_id: this.config.userId,
                });
                const { err_no, data, has_more } = res;
                if (err_no === 0 && data) {
                    articleIds.push(...data.map((x) => (this.config.cookie ? x.draft_id : x.article_id)));
                }
                if (has_more) {
                    cursor += 10;
                }
                else {
                    break;
                }
            }
            return articleIds;
        });
    }
    getDetail(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const { data: { data: { article_info: { content, ctime, mark_content, title }, tags, category, }, }, } = yield axios_1.default.post('https://api.juejin.cn/content_api/v1/article/detail', {
                article_id: id,
            });
            return {
                title,
                tags: tags.map((x) => x.tag_name),
                content: mark_content || sitdown.HTMLToMD(content),
                categories: [category === null || category === void 0 ? void 0 : category.category_name],
                date: new Date(Number(ctime) * 1000).toLocaleString('zh-CN', {
                    timeZone: 'Asia/Shanghai',
                }),
            };
        });
    }
    getDetail2(draftId) {
        return __awaiter(this, void 0, void 0, function* () {
            const { data: { data: { article_draft: { mark_content, title, ctime }, category: { category_name }, tags, }, }, } = yield axios_1.default.post('https://juejin.cn/content_api/v1/article_draft/detail', {
                draft_id: draftId,
            });
            return {
                content: mark_content,
                title,
                date: new Date(Number(ctime) * 1000).toLocaleString('zh-CN', {
                    timeZone: 'Asia/Shanghai',
                }),
                categories: [category_name],
                tags: tags.map((x) => x.tag_name),
            };
        });
    }
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            const list = yield this.getMain();
            const resultList = [];
            if (this.config.cookie) {
                log_1.info('提供cookie');
            }
            else {
                log_1.info('无cookie');
            }
            for (const id of list) {
                log_1.info(`拉取:${id}`);
                let result = null;
                if (this.config.cookie) {
                    result = yield this.getDetail2(id);
                }
                else {
                    result = yield this.getDetail(id);
                }
                resultList.push(result);
            }
            return resultList;
        });
    }
}
__decorate([
    decorator_1.catchCount()
], Juejin.prototype, "getDetail", null);
__decorate([
    decorator_1.catchCount()
], Juejin.prototype, "getDetail2", null);
exports.Juejin = Juejin;
//# sourceMappingURL=index.js.map